@@ -15,10 +15,20 @@ type PR struct {
 	MergeCommit string
 }
 
+// PRDetails encapsulates all relevant information about a Pull Request.
+type PRDetails struct {
+	*PR
+	State     string
+	Mergeable bool
+}
+
 type PRCommit struct {
 	SHA     string
 	Message string
 	Author  string
+	Email   string    // Author email from GitHub API, empty if not public
+	Date    time.Time // Timestamp field
+	Parents []string  // Parent commits (for merge detection)
 }
 
 // GraphQL query structures for hasura client
@@ -43,9 +53,10 @@ type PullRequestsQuery struct {
 				Commits struct {
 					Nodes []struct {
 						Commit struct {
-							OID     string `graphql:"oid"`
-							Message string
-							Author  struct {
+							OID          string `graphql:"oid"`
+							Message      string
+							AuthoredDate time.Time `graphql:"authoredDate"`
+							Author       struct {
 								Name string
 							}
 						}
