@@ -20,6 +20,11 @@ func TestCreateClient(t *testing.T) {
 			provider: "Groq",
 			exists:   true,
 		},
+		{
+			name:     "Existing provider - Z AI",
+			provider: "Z AI",
+			exists:   true,
+		},
 		{
 			name:     "Non-existent provider",
 			provider: "NonExistent",
